### HTMLTagLib by Micah Hanevich (Swordsman300) <br>
This Module / Library is designed to be an easy-to-implement HTML Element source for Bottle (and other) projects. <br>
HTML Element Definitions and Documentation pulled from [W3Schools' HTML Reference](https://www.w3schools.com/tags/default.asp). <br>
Intended for use with HTML5 and a [Python Bottle Framework](https://bottlepy.org/docs/dev/).
